### Name: markcorr
### Title: Mark Correlation Function
### Aliases: markcorr
### Keywords: spatial

### ** Examples

    require(spatstat)

    # CONTINUOUS-VALUED MARKS:
    # (1) Longleaf Pine data
    # marks represent tree diameter
    data(longleaf)
    # Subset of this large pattern
    swcorner <- owin(c(0,100),c(0,100))
    sub <- longleaf[ , swcorner]
    # mark correlation function
    mc <- markcorr(sub)
    conspire(mc, cbind(trans,theo) ~ r, xlim=c(0,40),ylim=c(0,2))

    # (2) simulated data with independent marks
    X <- rpoispp(100)
    X$marks <- runif(X$n)
    Xc <- markcorr(X)
    conspire(Xc, cbind(iso,trans,theo) ~ r, xlim=c(0,0.4),ylim=c(0,2))
    
    # MULTITYPE DATA:
    # Hughes' amacrine data
    # Cells marked as 'on'/'off'
    data(amacrine)
    # (3) Kernel density estimate with Epanecnikov kernel
    # (as proposed by Stoyan & Stoyan)
    M <- markcorr(amacrine, function(m1,m2) {m1==m2},
                  correction="translate", method="density",
                  kernel="epanechnikov")
    conspire(M, cbind(trans, theo) ~ r, subset="r <= 0.5")
    # Note: kernel="epanechnikov" comes from help(density)

    # (4) Same again with explicit control over bandwidth
    M <- markcorr(amacrine, function(m1,m2) {m1==m2},
                  correction="translate", method="density",
                  kernel="epanechnikov", bw=0.02)
    # see help(density) for correct interpretation of 'bw'

   
    data(ganglia)
    niets <- markcorr(ganglia, function(m1,m2){m1 == m2}, method="loess")
    niets <- markcorr(X, correction="isotropic", method="smrep")
    



